# -*- coding: utf-8 -*-
#Copyright (C) 2010, 2011 Seán Hayes
#
#Licensed under a BSD 3-Clause License. See LICENSE file.

from django.conf import settings
import os
import defaults

def patch_settings():
	if not hasattr(settings, 'PROJECT_ROOT'):
		settings.PROJECT_ROOT = defaults.PROJECT_ROOT
	
	if not hasattr(settings, 'PROJECT_PARENT_DIR'):
		settings.PROJECT_PARENT_DIR = os.path.dirname(settings.PROJECT_ROOT)
	
	if not hasattr(settings, 'LOG_DIR'):
		settings.LOG_DIR = defaults.LOG_DIR
	
	if not hasattr(settings, 'CONFIG_GEN_TEMPLATES_DIR'):
		settings.CONFIG_GEN_TEMPLATES_DIR = defaults.TEMPLATES_DIR
	
	if not hasattr(settings, 'CONFIG_GEN_GENERATED_DIR'):
		settings.CONFIG_GEN_GENERATED_DIR = defaults.GENERATED_DIR
	
	if not hasattr(settings, 'CONFIG_GEN_CONTEXT_PROCESSORS'):
		settings.CONFIG_GEN_CONTEXT_PROCESSORS = defaults.CONTEXT_PROCESSORS
	
	if not hasattr(settings, 'HOST'):
		settings.HOST = defaults.HOST



# -*- coding: utf-8 -*-
#Copyright (C) 2010, 2011 Seán Hayes
#
#Licensed under a BSD 3-Clause License. See LICENSE file.

import __main__
import os
from django.contrib.sites.models import Site
from django.db import transaction

PROJECT_ROOT = os.path.abspath(os.path.dirname(__main__.__file__))
LOG_DIR = os.path.join(PROJECT_ROOT, 'logs')

_config_dir = os.path.join(PROJECT_ROOT, 'config')
TEMPLATES_DIR = os.path.join(_config_dir, 'templates')
GENERATED_DIR = os.path.join(_config_dir, 'generated')

CONTEXT_PROCESSORS = []

#Error is thrown when running "./manage.py syncdb" for the first time and this app is installed.
try:
	HOST = Site.objects.get_current().domain.split(':')[0]
except:
	#try/except to avoid "django.db.transaction.TransactionManagementError: This code isn't under transaction management"
	try:
		transaction.rollback()
	except:
		pass
	HOST = 'localhost'




# -*- coding: utf-8 -*-
#Copyright (C) 2010, 2011 Seán Hayes
#
#Licensed under a BSD 3-Clause License. See LICENSE file.

VERSION = (1, 0, 6)

__version__ = "".join([".".join(map(str, VERSION[0:3])), "".join(VERSION[3:])])



#!/usr/bin/env python
import os, sys
import settings
from django.core.management import call_command

os.environ['DJANGO_SETTINGS_MODULE'] = '%s.settings' % settings.PROJECT_MODULE
sys.path.insert(0, settings.PROJECT_PARENT_DIR)

def runtests():
	call_command('test', 'django_config_gen')
	sys.exit()

if __name__ == '__main__':
	runtests()



# Django settings for django_config_gen_test_project project.

import os
import django.conf.global_settings as DEFAULT_SETTINGS

PROJECT_ROOT = os.path.abspath(os.path.dirname(__file__))
PROJECT_PARENT_DIR = os.path.dirname(PROJECT_ROOT)

PROJECT_MODULE = __name__[:__name__.rfind('.')] if '.' in __name__ else PROJECT_ROOT.split(os.sep)[-1]

DEBUG = True
TEMPLATE_DEBUG = DEBUG

ADMINS = (
	# ('Your Name', 'your_email@example.com'),
)

MANAGERS = ADMINS

DATABASES = {
	'default': {
		'ENGINE': 'django.db.backends.sqlite3', # Add 'postgresql_psycopg2', 'postgresql', 'mysql', 'sqlite3' or 'oracle'.
		'NAME': '',					  # Or path to database file if using sqlite3.
		'USER': '',					  # Not used with sqlite3.
		'PASSWORD': '',				  # Not used with sqlite3.
		'HOST': '',					  # Set to empty string for localhost. Not used with sqlite3.
		'PORT': '',					  # Set to empty string for default. Not used with sqlite3.
	}
}

# Local time zone for this installation. Choices can be found here:
# http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
# although not all choices may be available on all operating systems.
# On Unix systems, a value of None will cause Django to use the same
# timezone as the operating system.
# If running in a Windows environment this must be set to the same as your
# system time zone.
TIME_ZONE = 'America/Chicago'

# Language code for this installation. All choices can be found here:
# http://www.i18nguy.com/unicode/language-identifiers.html
LANGUAGE_CODE = 'en-us'

SITE_ID = 1

# If you set this to False, Django will make some optimizations so as not
# to load the internationalization machinery.
USE_I18N = True

# If you set this to False, Django will not format dates, numbers and
# calendars according to the current locale
USE_L10N = True

# Absolute filesystem path to the directory that will hold user-uploaded files.
# Example: "/home/media/media.lawrence.com/media/"
MEDIA_ROOT = ''

# URL that handles the media served from MEDIA_ROOT. Make sure to use a
# trailing slash.
# Examples: "http://media.lawrence.com/media/", "http://example.com/media/"
MEDIA_URL = ''

# Absolute path to the directory static files should be collected to.
# Don't put anything in this directory yourself; store your static files
# in apps' "static/" subdirectories and in STATICFILES_DIRS.
# Example: "/home/media/media.lawrence.com/static/"
STATIC_ROOT = ''

# URL prefix for static files.
# Example: "http://media.lawrence.com/static/"
STATIC_URL = '/static/'

# URL prefix for admin static files -- CSS, JavaScript and images.
# Make sure to use a trailing slash.
# Examples: "http://foo.com/static/admin/", "/static/admin/".
ADMIN_MEDIA_PREFIX = '/static/admin/'

# Additional locations of static files
STATICFILES_DIRS = (
	# Put strings here, like "/home/html/static" or "C:/www/django/static".
	# Always use forward slashes, even on Windows.
	# Don't forget to use absolute paths, not relative paths.
)

# List of finder classes that know how to find static files in
# various locations.
STATICFILES_FINDERS = (
	'django.contrib.staticfiles.finders.FileSystemFinder',
	'django.contrib.staticfiles.finders.AppDirectoriesFinder',
#	'django.contrib.staticfiles.finders.DefaultStorageFinder',
)

# Make this unique, and don't share it with anybody.
SECRET_KEY = ')v)jqp7voco+%3-9&75)i=u_j8u)+q1-3e&#fx=y#n+jk=!hxt'

# List of callables that know how to import templates from various sources.
TEMPLATE_LOADERS = (
	'django.template.loaders.filesystem.Loader',
	'django.template.loaders.app_directories.Loader',
#	 'django.template.loaders.eggs.Loader',
)

MIDDLEWARE_CLASSES = (
	'django.middleware.common.CommonMiddleware',
	'django.contrib.sessions.middleware.SessionMiddleware',
	'django.middleware.csrf.CsrfViewMiddleware',
	'django.contrib.auth.middleware.AuthenticationMiddleware',
	'django.contrib.messages.middleware.MessageMiddleware',
)

ROOT_URLCONF = 'django_config_gen_test_project.urls'

TEMPLATE_DIRS = (
	# Put strings here, like "/home/html/django_templates" or "C:/www/django/templates".
	# Always use forward slashes, even on Windows.
	# Don't forget to use absolute paths, not relative paths.
)

INSTALLED_APPS = (
	'django.contrib.auth',
	'django.contrib.contenttypes',
	'django.contrib.sessions',
	'django.contrib.sites',
	'django.contrib.messages',
	'django.contrib.staticfiles',
	# Uncomment the next line to enable the admin:
	# 'django.contrib.admin',
	# Uncomment the next line to enable admin documentation:
	# 'django.contrib.admindocs',
	
	#app that we want to test
	'django_config_gen',
)

# A sample logging configuration. The only tangible logging
# performed by this configuration is to send an email to
# the site admins on every HTTP 500 error.
# See http://docs.djangoproject.com/en/dev/topics/logging for
# more details on how to customize your logging configuration.
LOGGING = {
	'version': 1,
	'disable_existing_loggers': False,
	'handlers': {
		'mail_admins': {
			'level': 'ERROR',
			'class': 'django.utils.log.AdminEmailHandler'
		}
	},
	'loggers': {
		'django.request': {
			'handlers': ['mail_admins'],
			'level': 'ERROR',
			'propagate': True,
		},
	}
}



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup
import django_config_gen

package_name = 'django_config_gen'
test_package_name = '%s_test_project' % package_name

setup(name='django-config-gen',
	version=django_config_gen.__version__,
	description="Generates configuration files for Apache, Nginx, etc. using values in settings.py and the Django template system. You can write your own templates for whatever text based config file you need.",
	author='Seán Hayes',
	author_email='sean@seanhayes.name',
	classifiers=[
		"Development Status :: 5 - Production/Stable",
		"Framework :: Django",
		"Intended Audience :: Developers",
		"Intended Audience :: System Administrators",
		"License :: OSI Approved :: BSD License",
		"Operating System :: OS Independent",
		"Programming Language :: Python",
		"Programming Language :: Python :: 2.6",
		"Topic :: Internet :: WWW/HTTP :: Dynamic Content",
		"Topic :: Internet :: WWW/HTTP :: Site Management",
		"Topic :: Software Development :: Build Tools",
		"Topic :: Software Development :: Code Generators",
		"Topic :: Software Development :: Libraries",
		"Topic :: Software Development :: Libraries :: Python Modules"
	],
	keywords='django configuration generator',
	url='http://seanhayes.name/',
	download_url='https://github.com/SeanHayes/django-config-gen',
	license='BSD',
	packages=[
		'django_config_gen',
		'django_config_gen_test_project',
	],
	package_data={'django_config_gen': ['management/commands/example_templates/*']},
	include_package_data=True,
	install_requires=['Django>=1.2',],
	test_suite = '%s.runtests.runtests' % test_package_name,
)

